Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RegisterChatServiceServer ¶
func RegisterChatServiceServer(s *grpc.Server, srv ChatServiceServer)
Types ¶
type ChatServiceClient ¶
type ChatServiceClient interface {
// Send sends message to the server
Send(ctx context.Context, in *wrappers.StringValue, opts ...grpc.CallOption) (*empty.Empty, error)
// Subscribe is streaming method to get echo messages from the server
Subscribe(ctx context.Context, in *empty.Empty, opts ...grpc.CallOption) (ChatService_SubscribeClient, error)
}
ChatServiceClient is the client API for ChatService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
func NewChatServiceClient ¶
func NewChatServiceClient(cc *grpc.ClientConn) ChatServiceClient
type ChatServiceServer ¶
type ChatServiceServer interface {
// Send sends message to the server
Send(context.Context, *wrappers.StringValue) (*empty.Empty, error)
// Subscribe is streaming method to get echo messages from the server
Subscribe(*empty.Empty, ChatService_SubscribeServer) error
}
ChatServiceServer is the server API for ChatService service.
type ChatService_SubscribeClient ¶
type ChatService_SubscribeClient interface {
Recv() (*wrappers.StringValue, error)
grpc.ClientStream
}
type ChatService_SubscribeServer ¶
type ChatService_SubscribeServer interface {
Send(*wrappers.StringValue) error
grpc.ServerStream
}
type UnimplementedChatServiceServer ¶
type UnimplementedChatServiceServer struct {
}
UnimplementedChatServiceServer can be embedded to have forward compatible implementations.
func (*UnimplementedChatServiceServer) Send ¶
func (*UnimplementedChatServiceServer) Send(ctx context.Context, req *wrappers.StringValue) (*empty.Empty, error)
func (*UnimplementedChatServiceServer) Subscribe ¶
func (*UnimplementedChatServiceServer) Subscribe(req *empty.Empty, srv ChatService_SubscribeServer) error
Click to show internal directories.
Click to hide internal directories.